import type { MessageMetricsManager, ProcessedMessageMetadata } from '@message-queue-toolkit/core';
import type { Histogram } from 'prom-client';
import promClient from 'prom-client';
/**
 * Parameters used for registering message processing metrics in Prometheus
 */
type PrometheusMetricParams<T extends object> = {
    /**
     * Prometheus metric name
     */
    name: string;
    /**
     * Prometheus metric description
     */
    helpDescription: string;
    /**
     * Buckets used to configure Histogram metric
     */
    buckets: number[];
    /**
     * Message version used as a label - can be static string or method resolving version based on payload
     */
    messageVersion?: string | MessageVersionGeneratingFunction<T>;
};
type MessageVersionGeneratingFunction<T extends object> = (messageMetadata: ProcessedMessageMetadata<T>) => string | undefined;
/**w
 * Implementation of MessageMetricsManager that can be used to register message processing measurements in Prometheus utilizing Histogram
 */
export declare abstract class MessageProcessingPrometheusMetric<MessagePayloadSchemas extends object> implements MessageMetricsManager<MessagePayloadSchemas> {
    protected readonly metricParams: PrometheusMetricParams<MessagePayloadSchemas>;
    /** Fallbacks to null if metrics are disabled on app level */
    protected readonly metric: Histogram<'messageType' | 'version' | 'queue' | 'result'>;
    protected readonly messageVersionGeneratingFunction: MessageVersionGeneratingFunction<MessagePayloadSchemas>;
    /**
     * @param metricParams - metrics parameters (see PrometheusMetricParams)
     * @param client - use it to specify custom Prometheus client
     */
    constructor(metricParams: PrometheusMetricParams<MessagePayloadSchemas>, client?: typeof promClient);
    protected abstract calculateObservedValue(metadata: ProcessedMessageMetadata<MessagePayloadSchemas>): number | null;
    registerProcessedMessage(metadata: ProcessedMessageMetadata<MessagePayloadSchemas>): void;
    protected registerMetric(client: typeof promClient): Histogram;
    protected resolveMessageVersionGeneratingFunction(metricParams: PrometheusMetricParams<MessagePayloadSchemas>): MessageVersionGeneratingFunction<MessagePayloadSchemas>;
}
export {};
