"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessageProcessingPrometheusMetric = void 0;
const tslib_1 = require("tslib");
const prom_client_1 = tslib_1.__importDefault(require("prom-client"));
/**w
 * Implementation of MessageMetricsManager that can be used to register message processing measurements in Prometheus utilizing Histogram
 */
class MessageProcessingPrometheusMetric {
    metricParams;
    /** Fallbacks to null if metrics are disabled on app level */
    metric;
    messageVersionGeneratingFunction;
    /**
     * @param metricParams - metrics parameters (see PrometheusMetricParams)
     * @param client - use it to specify custom Prometheus client
     */
    constructor(metricParams, client) {
        this.metricParams = metricParams;
        this.messageVersionGeneratingFunction =
            this.resolveMessageVersionGeneratingFunction(metricParams);
        this.metric = this.registerMetric(client ?? prom_client_1.default);
    }
    registerProcessedMessage(metadata) {
        const observedValue = this.calculateObservedValue(metadata);
        if (observedValue === null) {
            // Data not available, skipping
            return;
        }
        this.metric.observe({
            messageType: metadata.messageType,
            version: this.messageVersionGeneratingFunction(metadata),
            queue: metadata.queueName,
            result: metadata.processingResult,
        }, observedValue);
    }
    registerMetric(client) {
        const existingMetric = client.register.getSingleMetric(this.metricParams.name);
        if (existingMetric) {
            return existingMetric;
        }
        return new client.Histogram({
            name: this.metricParams.name,
            help: this.metricParams.helpDescription,
            buckets: this.metricParams.buckets,
            labelNames: ['messageType', 'version', 'queue', 'result'],
        });
    }
    resolveMessageVersionGeneratingFunction(metricParams) {
        const messageVersion = metricParams.messageVersion;
        return typeof messageVersion === 'function' ? messageVersion : () => messageVersion;
    }
}
exports.MessageProcessingPrometheusMetric = MessageProcessingPrometheusMetric;
//# sourceMappingURL=MessageProcessingPrometheusMetric.js.map